.. _interactive-notebooks:

**************************
Interactive Mode Notebooks
**************************

We present some notebooks demonstrating usage of RAIL in interactive mode, for
different workflows.

